@@ -130,6 +130,34 @@ def parse_args():
         default=None,
         dest="self_hosted_swagger",
     )
+    parser.add_argument(
+        "--prometheus",
+        help="Add prometheus integration",
+        action="store_true",
+        default=None,
+        dest="prometheus_enabled",
+    )
+    parser.add_argument(
+        "--sentry",
+        help="Add sentry integration",
+        action="store_true",
+        default=None,
+        dest="sentry_enabled",
+    )
+    parser.add_argument(
+        "--loguru",
+        help="Add loguru logger",
+        action="store_true",
+        default=None,
+        dest="enable_loguru",
+    )
+    parser.add_argument(
+        "--opentelemetry",
+        help="Add opentelemetry integration",
+        action="store_true",
+        default=None,
+        dest="otlp_enabled",
+    )
     parser.add_argument(
         "--force",
         help="Owerrite directory if it exists",
@@ -170,6 +198,22 @@ def ask_features(current_context: BuilderContext) -> BuilderContext:
             "name": "enable_rmq",
             "value": current_context.enable_rmq,
         },
+        "Prometheus integration": {
+            "name": "prometheus_enabled",
+            "value": current_context.prometheus_enabled,
+        },
+        "Sentry integration": {
+            "name": "sentry_enabled",
+            "value": current_context.sentry_enabled,
+        },
+        "Opentelemetry integration": {
+            "name": "otlp_enabled",
+            "value": current_context.otlp_enabled,
+        },
+        "Loguru logger": {
+            "name": "enable_loguru",
+            "value": current_context.enable_loguru,
+        },
     }
     if current_context.db != DatabaseType.none:
         features["Migrations support"] = {
