@@ -1,6 +1,6 @@
 from typing import AsyncGenerator
 
-from aioredis import Redis
+from redis.asyncio import Redis
 from starlette.requests import Request
 
 
