@@ -1,5 +1,5 @@
 from fastapi import FastAPI
-import aioredis
+from redis.asyncio import ConnectionPool
 from {{cookiecutter.project_name}}.settings import settings
 
 
@@ -9,7 +9,7 @@ def init_redis(app: FastAPI) -> None:
 
     :param app: current fastapi application.
     """
-    app.state.redis_pool = aioredis.ConnectionPool.from_url(
+    app.state.redis_pool = ConnectionPool.from_url(
         str(settings.redis_url),
     )
 
